pub fn loading<V>(value: V) -> Attr<Loading, V>where
V: AttributeValue,Expand description
The loading attribute indicates how the browser should load the image.
pub fn loading<V>(value: V) -> Attr<Loading, V>where
V: AttributeValue,The loading attribute indicates how the browser should load the image.