pub struct ChildrenOptContainer<T>(pub T);Expand description
Compiler optimisation, can be used with certain type to avoid unique closures in the view!{} macro.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T> ToChildren<ChildrenOptContainer<T>> for ChildrenFn
impl<T> ToChildren<ChildrenOptContainer<T>> for ChildrenFn
Sourcefn to_children(t: ChildrenOptContainer<T>) -> Self
fn to_children(t: ChildrenOptContainer<T>) -> Self
Convert the provided type (generally a closure) to Self (generally a “children” type,
e.g., Children). See the implementations to see exactly which input types are supported
and which “children” type they are converted to.
Sourceimpl<T> ToChildren<ChildrenOptContainer<T>> for ChildrenFragmentFn
impl<T> ToChildren<ChildrenOptContainer<T>> for ChildrenFragmentFn
Sourcefn to_children(t: ChildrenOptContainer<T>) -> Self
fn to_children(t: ChildrenOptContainer<T>) -> Self
Convert the provided type (generally a closure) to Self (generally a “children” type,
e.g., Children). See the implementations to see exactly which input types are supported
and which “children” type they are converted to.
Sourceimpl<T> ToChildren<ChildrenOptContainer<T>> for Box<dyn Fn() -> AnyView + Send>
impl<T> ToChildren<ChildrenOptContainer<T>> for Box<dyn Fn() -> AnyView + Send>
Sourcefn to_children(t: ChildrenOptContainer<T>) -> Self
fn to_children(t: ChildrenOptContainer<T>) -> Self
Convert the provided type (generally a closure) to Self (generally a “children” type,
e.g., Children). See the implementations to see exactly which input types are supported
and which “children” type they are converted to.
Sourceimpl<T> ToChildren<ChildrenOptContainer<T>> for ChildrenFnMut
impl<T> ToChildren<ChildrenOptContainer<T>> for ChildrenFnMut
Sourcefn to_children(t: ChildrenOptContainer<T>) -> Self
fn to_children(t: ChildrenOptContainer<T>) -> Self
Convert the provided type (generally a closure) to Self (generally a “children” type,
e.g., Children). See the implementations to see exactly which input types are supported
and which “children” type they are converted to.
Sourceimpl<T> ToChildren<ChildrenOptContainer<T>> for ChildrenFragmentMut
impl<T> ToChildren<ChildrenOptContainer<T>> for ChildrenFragmentMut
Sourcefn to_children(t: ChildrenOptContainer<T>) -> Self
fn to_children(t: ChildrenOptContainer<T>) -> Self
Convert the provided type (generally a closure) to Self (generally a “children” type,
e.g., Children). See the implementations to see exactly which input types are supported
and which “children” type they are converted to.
Sourceimpl<T> ToChildren<ChildrenOptContainer<T>> for Children
impl<T> ToChildren<ChildrenOptContainer<T>> for Children
Sourcefn to_children(t: ChildrenOptContainer<T>) -> Self
fn to_children(t: ChildrenOptContainer<T>) -> Self
Convert the provided type (generally a closure) to Self (generally a “children” type,
e.g., Children). See the implementations to see exactly which input types are supported
and which “children” type they are converted to.
Sourceimpl<T> ToChildren<ChildrenOptContainer<T>> for ChildrenFragment
impl<T> ToChildren<ChildrenOptContainer<T>> for ChildrenFragment
Sourcefn to_children(t: ChildrenOptContainer<T>) -> Self
fn to_children(t: ChildrenOptContainer<T>) -> Self
Convert the provided type (generally a closure) to Self (generally a “children” type,
e.g., Children). See the implementations to see exactly which input types are supported
and which “children” type they are converted to.
Sourceimpl<T> ToChildren<ChildrenOptContainer<T>> for TypedChildren<T>where
T: IntoView + 'static,
impl<T> ToChildren<ChildrenOptContainer<T>> for TypedChildren<T>where
T: IntoView + 'static,
Sourcefn to_children(t: ChildrenOptContainer<T>) -> Self
fn to_children(t: ChildrenOptContainer<T>) -> Self
Convert the provided type (generally a closure) to Self (generally a “children” type,
e.g., Children). See the implementations to see exactly which input types are supported
and which “children” type they are converted to.
Sourceimpl<T> ToChildren<ChildrenOptContainer<T>> for TypedChildrenFn<T>
impl<T> ToChildren<ChildrenOptContainer<T>> for TypedChildrenFn<T>
Sourcefn to_children(t: ChildrenOptContainer<T>) -> Self
fn to_children(t: ChildrenOptContainer<T>) -> Self
Convert the provided type (generally a closure) to Self (generally a “children” type,
e.g., Children). See the implementations to see exactly which input types are supported
and which “children” type they are converted to.
Sourceimpl<T> ToChildren<ChildrenOptContainer<T>> for TypedChildrenMut<T>
impl<T> ToChildren<ChildrenOptContainer<T>> for TypedChildrenMut<T>
Sourcefn to_children(t: ChildrenOptContainer<T>) -> Self
fn to_children(t: ChildrenOptContainer<T>) -> Self
Convert the provided type (generally a closure) to Self (generally a “children” type,
e.g., Children). See the implementations to see exactly which input types are supported
and which “children” type they are converted to.