pub struct ErrorHookFuture<Fut> { /* private fields */ }Expand description
A Future that reads the error hook that is set when it is created, and sets this as the
current error hook whenever it is polled.
Implementations
Sourceimpl<Fut> ErrorHookFuture<Fut>
impl<Fut> ErrorHookFuture<Fut>
Sourcepub fn new(inner: Fut) -> ErrorHookFuture<Fut> ⓘ
pub fn new(inner: Fut) -> ErrorHookFuture<Fut> ⓘ
Reads the current hook and wraps the given Future, returning a new Future that will
set the error hook whenever it is polled.