section

Function section 

pub fn section() -> HtmlElement<Section, (), ()>
The <section> HTML element represents a generic standalone section of a document, which doesn’t have a more specific semantic element to represent it. Sections should always have a heading, with very few exceptions.