macro_rules! error {
($($t:tt)*) => { ... };
}Expand description
Uses println!()-style formatting to log errors to the console (in the browser)
or via eprintln!() (if not in the browser).
macro_rules! error {
($($t:tt)*) => { ... };
}Uses println!()-style formatting to log errors to the console (in the browser)
or via eprintln!() (if not in the browser).