pub enum SignalReadGuard<T, S>where
T: 'static,
S: Storage<T>,{
Read(ReadGuard<T, Plain<T>>),
Memo(ReadGuard<T, Mapped<Plain<Option<<S as Storage<T>>::Wrapped>>, T>>),
Owned(T),
}Expand description
The content of a Signal wrapper read guard, variable depending on the signal type.
Variants
Read(ReadGuard<T, Plain<T>>)
A read signal guard.
Memo(ReadGuard<T, Mapped<Plain<Option<<S as Storage<T>>::Wrapped>>, T>>)
A memo guard.
Owned(T)
A fake guard for derived signals, the content had to actually be cloned, so it’s not a guard but we pretend it is.