pub struct AnySubscriber(pub usize, pub Weak<dyn Subscriber + Send + Sync>);Expand description
A type-erased subscriber.
Tuple Fields
0: usize1: Weak<dyn Subscriber + Send + Sync>Trait Implementations
Sourceimpl Clone for AnySubscriber
impl Clone for AnySubscriber
Sourcefn clone(&self) -> AnySubscriber
fn clone(&self) -> AnySubscriber
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnySubscriber
impl Debug for AnySubscriber
Sourceimpl Hash for AnySubscriber
impl Hash for AnySubscriber
Sourceimpl PartialEq for AnySubscriber
impl PartialEq for AnySubscriber
Sourceimpl ReactiveNode for AnySubscriber
impl ReactiveNode for AnySubscriber
Sourcefn mark_dirty(&self)
fn mark_dirty(&self)
Notifies the source’s dependencies that it has changed.
Sourcefn mark_subscribers_check(&self)
fn mark_subscribers_check(&self)
Marks that all subscribers need to be checked.
Sourcefn update_if_necessary(&self) -> bool
fn update_if_necessary(&self) -> bool
Regenerates the value for this node, if needed, and returns whether
it has actually changed or not.
Sourcefn mark_check(&self)
fn mark_check(&self)
Notifies the source’s dependencies that it may have changed.
Sourceimpl Subscriber for AnySubscriber
impl Subscriber for AnySubscriber
Sourcefn add_source(&self, source: AnySource)
fn add_source(&self, source: AnySource)
Adds a subscriber to this subscriber’s list of dependencies.
Sourcefn clear_sources(&self, subscriber: &AnySubscriber)
fn clear_sources(&self, subscriber: &AnySubscriber)
Clears the set of sources for this subscriber.
Sourceimpl ToAnySubscriber for AnySubscriber
impl ToAnySubscriber for AnySubscriber
Sourcefn to_any_subscriber(&self) -> AnySubscriber
fn to_any_subscriber(&self) -> AnySubscriber
Converts this type to its type-erased equivalent.
Sourceimpl WithObserver for AnySubscriber
impl WithObserver for AnySubscriber
Sourcefn with_observer<T>(&self, fun: impl FnOnce() -> T) -> T
fn with_observer<T>(&self, fun: impl FnOnce() -> T) -> T
Runs the given function with this subscriber as the thread-local
Observer.Sourcefn with_observer_untracked<T>(&self, fun: impl FnOnce() -> T) -> T
fn with_observer_untracked<T>(&self, fun: impl FnOnce() -> T) -> T
Runs the given function with this subscriber as the thread-local
Observer,
but without tracking dependencies.impl Eq for AnySubscriber