WriteSignal

Struct WriteSignal 

pub struct WriteSignal<T, S = SyncStorage> { /* private fields */ }
An arena-allocated setter for a reactive signal.

A signal is a piece of data that may change over time, and notifies other code when it has changed.

This is an arena-allocated signal, which is Copy and is disposed when its reactive Owner cleans up. For a reference-counted signal that lives as long as a reference to it is alive, see ArcWriteSignal.

Core Trait Implementations

  • .set() sets the signal to a new value.
  • .update() updates the value of the signal by applying a closure that takes a mutable reference.
  • .write() returns a guard through which the signal can be mutated, and which notifies subscribers when it is dropped.

Each of these has a related _untracked() method, which updates the signal without notifying subscribers. Untracked updates are not desirable in most cases, as they cause “tearing” between the signal’s value and its observed value. If you want a non-reactive container, use ArenaItem instead.

Examples

let (count, set_count) = signal(0);

// ✅ calling the setter sets the value
//    `set_count(1)` on nightly
set_count.set(1);
assert_eq!(count.get(), 1);

// ❌ you could call the getter within the setter
// set_count.set(count.get() + 1);

// ✅ however it's more efficient to use .update() and mutate the value in place
set_count.update(|count: &mut i32| *count += 1);
assert_eq!(count.get(), 2);

// ✅ `.write()` returns a guard that implements `DerefMut` and will notify when dropped
*set_count.write() += 1;
assert_eq!(count.get(), 3);