FromToBytesCodec

Struct FromToBytesCodec 

pub struct FromToBytesCodec;
A binary codec that uses rust own binary encoding functions to encode and decode data. This can be used if you want to encode only primitives and don’t want to rely on third party crates like bincode or rmp-serde. If you have more complex data check out [BincodeSerdeCodec] or [MsgpackSerdeCodec].