pub struct TupleStructCheckContext {
pub tuple_struct_name: &'static str,
pub field_index: usize,
}Expand description
Context for errors resulting from invalid tuple structs.
This context is used by the derive macro to trace which field of a tuple struct failed validation.
Fields
tuple_struct_name: &'static strThe name of the tuple struct with an invalid field.
field_index: usizeThe index of the tuple struct field that was invalid.