pub struct Errors(/* private fields */);Expand description
A struct to hold all the possible errors that could be provided by child Views
Implementations
Sourceimpl Errors
impl Errors
Sourcepub fn insert<E>(&mut self, key: ErrorId, error: E)
pub fn insert<E>(&mut self, key: ErrorId, error: E)
Add an error to Errors that will be processed by <ErrorBoundary/>
Sourcepub fn insert_with_default_key<E>(&mut self, error: E)
pub fn insert_with_default_key<E>(&mut self, error: E)
Add an error with the default key for errors outside the reactive system