pub fn noscript() -> HtmlElement<Noscript, (), ()>Expand description
The <noscript> HTML element defines a section of HTML to be inserted if a script type on the page is unsupported or if scripting is currently turned off in the browser.
pub fn noscript() -> HtmlElement<Noscript, (), ()>The <noscript> HTML element defines a section of HTML to be inserted if a script type on the page is unsupported or if scripting is currently turned off in the browser.