pub struct Signal<T, S = SyncStorage>where
S: Storage<T>,{ /* private fields */ }Expand description
A wrapper for any kind of arena-allocated reactive signal:
a ReadSignal, Memo, RwSignal, or derived signal closure,
or a plain value of the same type
This allows you to create APIs that take T or any reactive value that returns T
as an argument, rather than adding a generic F: Fn() -> T.
Values can be accessed with the same function call, read(), with(), and get()
APIs as other signals.
Important Notes about Derived Signals
Signal::derive() is simply a way to box and type-erase a “derived signal,” which
is a plain closure that accesses one or more signals. It does not cache the value
of that computation. Accessing the value of a Signal<_> that is created using Signal::derive()
will run the closure again every time you call .read(), .with(), or .get().
If you want the closure to run the minimal number of times necessary to update its state,
and then to cache its value, you should use a Memo (and convert it into a Signal<_>)
rather than using Signal::derive().
Note that for many computations, it is nevertheless less expensive to use a derived signal than to create a separate memo and to cache the value: creating a new reactive node and taking the lock on that cached value whenever you access the signal is more expensive than simply re-running the calculation in many cases.
Implementations
Sourceimpl<T> Signal<T>
impl<T> Signal<T>
Sourcepub fn derive(
derived_signal: impl Fn() -> T + Send + Sync + 'static,
) -> Signal<T>
pub fn derive( derived_signal: impl Fn() -> T + Send + Sync + 'static, ) -> Signal<T>
Wraps a derived signal, i.e., any computation that accesses one or more reactive signals.
let (count, set_count) = signal(2);
let double_count = Signal::derive(move || count.get() * 2);
// this function takes any kind of wrapped signal
fn above_3(arg: &Signal<i32>) -> bool {
arg.get() > 3
}
assert_eq!(above_3(&count.into()), false);
assert_eq!(above_3(&double_count), true);Sourcepub fn stored(value: T) -> Signal<T>
pub fn stored(value: T) -> Signal<T>
Moves a static, nonreactive value into a signal, backed by ArcStoredValue.
Sourceimpl<T> Signal<T, LocalStorage>where
T: 'static,
impl<T> Signal<T, LocalStorage>where
T: 'static,
Sourcepub fn derive_local(
derived_signal: impl Fn() -> T + 'static,
) -> Signal<T, LocalStorage>
pub fn derive_local( derived_signal: impl Fn() -> T + 'static, ) -> Signal<T, LocalStorage>
Wraps a derived signal. Works like Signal::derive but uses LocalStorage.
Sourcepub fn stored_local(value: T) -> Signal<T, LocalStorage>
pub fn stored_local(value: T) -> Signal<T, LocalStorage>
Moves a static, nonreactive value into a signal, backed by ArcStoredValue.
Works like Signal::stored but uses LocalStorage.