pub struct AllocError;🔬This is a nightly-only experimental API. (
allocator_api)Expand description
The AllocError error indicates an allocation failure
that may be due to resource exhaustion or to
something wrong when combining the given input arguments with this
allocator.