pub struct DebugSet<'a, 'b>where
'b: 'a,{ /* private fields */ }Expand description
A struct to help with fmt::Debug implementations.
This is useful when you wish to output a formatted set of items as a part
of your Debug::fmt implementation.
This can be constructed by the Formatter::debug_set method.
Examples
use std::fmt;
struct Foo(Vec<i32>);
impl fmt::Debug for Foo {
fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
fmt.debug_set().entries(self.0.iter()).finish()
}
}
assert_eq!(
format!("{:?}", Foo(vec![10, 11])),
"{10, 11}",
);Implementations
Sourceimpl<'a, 'b> DebugSet<'a, 'b>where
'b: 'a,
impl<'a, 'b> DebugSet<'a, 'b>where
'b: 'a,
1.2.0 · Sourcepub fn entry(&mut self, entry: &dyn Debug) -> &mut DebugSet<'a, 'b>
pub fn entry(&mut self, entry: &dyn Debug) -> &mut DebugSet<'a, 'b>
Adds a new entry to the set output.
Examples
use std::fmt;
struct Foo(Vec<i32>, Vec<u32>);
impl fmt::Debug for Foo {
fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
fmt.debug_set()
.entry(&self.0) // Adds the first "entry".
.entry(&self.1) // Adds the second "entry".
.finish()
}
}
assert_eq!(
format!("{:?}", Foo(vec![10, 11], vec![12, 13])),
"{[10, 11], [12, 13]}",
);Sourcepub fn entry_with<F>(&mut self, entry_fmt: F) -> &mut DebugSet<'a, 'b>
🔬This is a nightly-only experimental API. (debug_closure_helpers)
pub fn entry_with<F>(&mut self, entry_fmt: F) -> &mut DebugSet<'a, 'b>
debug_closure_helpers)Adds a new entry to the set output.
This method is equivalent to DebugSet::entry, but formats the
entry using a provided closure rather than by calling Debug::fmt.
1.2.0 · Sourcepub fn entries<D, I>(&mut self, entries: I) -> &mut DebugSet<'a, 'b>where
D: Debug,
I: IntoIterator<Item = D>,
pub fn entries<D, I>(&mut self, entries: I) -> &mut DebugSet<'a, 'b>where
D: Debug,
I: IntoIterator<Item = D>,
Adds the contents of an iterator of entries to the set output.
Examples
use std::fmt;
struct Foo(Vec<i32>, Vec<u32>);
impl fmt::Debug for Foo {
fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
fmt.debug_set()
.entries(self.0.iter()) // Adds the first "entry".
.entries(self.1.iter()) // Adds the second "entry".
.finish()
}
}
assert_eq!(
format!("{:?}", Foo(vec![10, 11], vec![12, 13])),
"{10, 11, 12, 13}",
);1.83.0 · Sourcepub fn finish_non_exhaustive(&mut self) -> Result<(), Error>
pub fn finish_non_exhaustive(&mut self) -> Result<(), Error>
Marks the set as non-exhaustive, indicating to the reader that there are some other elements that are not shown in the debug representation.
Examples
use std::fmt;
struct Foo(Vec<i32>);
impl fmt::Debug for Foo {
fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
// Print at most two elements, abbreviate the rest
let mut f = fmt.debug_set();
let mut f = f.entries(self.0.iter().take(2));
if self.0.len() > 2 {
f.finish_non_exhaustive()
} else {
f.finish()
}
}
}
assert_eq!(
format!("{:?}", Foo(vec![1, 2, 3, 4])),
"{1, 2, ..}",
);1.2.0 · Sourcepub fn finish(&mut self) -> Result<(), Error>
pub fn finish(&mut self) -> Result<(), Error>
Finishes output and returns any error encountered.
Examples
use std::fmt;
struct Foo(Vec<i32>);
impl fmt::Debug for Foo {
fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
fmt.debug_set()
.entries(self.0.iter())
.finish() // Ends the set formatting.
}
}
assert_eq!(
format!("{:?}", Foo(vec![10, 11])),
"{10, 11}",
);Auto Trait Implementations
impl<'a, 'b> Freeze for DebugSet<'a, 'b>
impl<'a, 'b> !RefUnwindSafe for DebugSet<'a, 'b>
impl<'a, 'b> !Send for DebugSet<'a, 'b>
impl<'a, 'b> !Sync for DebugSet<'a, 'b>
impl<'a, 'b> Unpin for DebugSet<'a, 'b>
impl<'a, 'b> UnsafeUnpin for DebugSet<'a, 'b>
impl<'a, 'b> !UnwindSafe for DebugSet<'a, 'b>